@@ -212,6 +212,7 @@ database_new_with_path (const char *path)
       fclose (fp);
     }
 
+  /* We need to check for duplicate item IDs here, don't we... */
   return db;
 }
 
@@ -313,3 +314,15 @@ database_item_index (struct database *db, struct item *it)
 
   return i;
 }
+
+size_t
+database_item_index_by_id (struct database *db, const char * const id)
+{
+  size_t i;
+
+  for (i = 0; i < db->nitems; i++)
+    if (strcmp (db->items[i]->identifier, id) == 0)
+      break;
+
+  return i;
+}
