@@ -36,5 +36,8 @@ void database_item_remove (struct database *db, int pos);
 /* Return the position of IT in DB->items, or DB->nitems if it is not
    present.  */
 size_t database_item_index (struct database *db, struct item *it);
+/* Return the position of an item with the identifier ID in DB->items, or
+   DB->nitems if it is not present.  */
+size_t database_item_index_by_id (struct database *db, const char *id);
 
 #endif /* TINA_DATABASE_H */
