@@ -7,6 +7,10 @@
 
 #define _GNU_SOURCE
 
+#include <errno.h>
+#include <fcntl.h>
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -16,6 +20,51 @@
 #include "item.h"
 #include "memory.h"
 
+static inline unsigned int
+get_srand_seed (void)
+{
+  {
+    unsigned int seed;
+    const int random_fd = open ("/dev/urandom", O_RDONLY);
+    if (random_fd != 0)
+    {
+      const ssize_t nread = read (random_fd, &seed, sizeof(seed));
+      close (random_fd);
+      if (nread > 0 && (size_t)nread == sizeof(seed))
+        return seed;
+    }
+  }
+
+  {
+    unsigned int seed;
+    const int random_fd = open ("/dev/random", O_RDONLY);
+    if (random_fd != 0)
+    {
+      const ssize_t nread = read (random_fd, &seed, sizeof(seed));
+      close (random_fd);
+      if (nread > 0 && (size_t)nread == sizeof(seed))
+        return seed;
+    }
+  }
+
+  /* OK, do it the old naive way. */
+  return (unsigned int)getpid () ^ (unsigned int)time (NULL);
+}
+
+static inline int
+rand_i (void)
+{
+  static bool initialized = false;
+
+  if (!initialized)
+  {
+    srand (get_srand_seed ());
+    initialized = true;
+  }
+
+  return rand();
+}
+
 /* Return a unique identifier.  */
 static char *
 unique_identifier (void)
@@ -23,7 +72,7 @@ unique_identifier (void)
   char buf[256];
   size_t len;
 
-  snprintf (buf, sizeof (buf), "<%lx.%x@", time (NULL), rand ());
+  snprintf (buf, sizeof (buf), "<%jx.%x@", (intmax_t)time (NULL), rand_i ());
   len = strlen (buf);
   gethostname (buf + len, sizeof (buf) - len - 1);
   strcat (buf, ">");
@@ -56,6 +105,32 @@ item_new_with_description (const char *description)
   return it;
 }
 
+void
+item_regenerate_id (struct item * const item)
+{
+  char * const p_dot = strchr (item->identifier, '.');
+  if (p_dot == NULL)
+    abort();
+  const char * const p_at = strchr (p_dot + 1, '@');
+  if (p_at == NULL)
+    abort();
+
+  errno = 0;
+  char *p_end;
+  const unsigned long current = strtoul (p_dot + 1, &p_end, 16);
+  if (p_end == NULL || *p_end != '@' || errno != 0)
+    abort();
+
+  char buf[256];
+  snprintf (buf, sizeof (buf), "%lx", current + 1);
+
+  const size_t len = strlen (buf);
+  if (p_dot + 1 + len != p_at )
+    abort();
+  memcpy (p_dot + 1, buf, len);
+}
+
+/* Is this function unused? If not, we need to check for duplicate item ID here. */
 struct item *
 item_clone (struct item *it)
 {
