@@ -27,6 +27,9 @@ struct item *item_clone (struct item *it);
 /* Delete IT.  */
 void item_delete (struct item *it);
 
+/* Generate a new ID for the item. */
+void item_regenerate_id (struct item *it);
+
 /* Set the identifier of IT to IDENTIFIER.  */
 void item_identifier_set (struct item *it, const char *identifier);
 /* Set the description of IT to DESCRIPTION.  */
