@@ -125,6 +125,16 @@ search_view (struct view *v, const char *pattern, int dir)
   regfree (&reg);
 }
 
+/* Create a new item with a unique (for this database) ID. */
+static struct item *
+unique_item_new_with_description (const struct view * const v, const char * const description)
+{
+  struct item * const it = item_new_with_description (description);
+  while (database_item_index_by_id (v->s->db, it->identifier) < v->s->db->nitems)
+    item_regenerate_id (it);
+  return it;
+}
+
 /* Read an item and add it at POS to V.  */
 static void
 read_item (struct view *v, int pos)
@@ -134,7 +144,7 @@ read_item (struct view *v, int pos)
   description = inquire ("Item: ", NULL);
   if (description != NULL)
     {
-      insert_item (v, pos, item_new_with_description (description));
+      insert_item (v, pos, unique_item_new_with_description (v, description));
       free (description);
     }
 }
@@ -161,7 +171,7 @@ cmd_categorize (struct view **v, struct item **clipboard __unused)
 	{
 	  struct item *it;
 
-	  it = item_new_with_description (category);
+	  it = unique_item_new_with_description ((*v), category);
 	  database_item_add ((*v)->s->db, it, (*v)->s->db->nitems);
 	  item_category_add ((*v)->s->items[(*v)->selected], it->identifier);
 	}
@@ -232,7 +242,7 @@ cmd_limit (struct view **v, struct item **clipboard __unused)
 	    {
 	      struct item *it;
 
-	      it = item_new_with_description (limit);
+	      it = unique_item_new_with_description ((*v), limit);
 	      database_item_add ((*v)->s->db, it, (*v)->s->db->nitems);
 	      selection_category_set (s, it->identifier);
 	    }
