@@ -30,12 +30,12 @@ class JSONFormatHandler(f_base.FormatHandler):
     """Encode and decode Tina database entries in a hierarchical structure."""
 
     @classmethod
-    def dumps(cls, entries: list[db.TinaEntry]) -> str:
+    def _do_dumps(cls, entries: list[db.TinaEntry]) -> str:
         """Format Tina database entries into the JSON structure."""
         return json.dumps(f_base.serialize(entries))
 
     @classmethod
-    def loads(cls, contents: str) -> list[db.TinaEntry]:
+    def _do_loads(cls, contents: str) -> list[db.TinaEntry]:
         """Parse the JSON structure into database entries."""
         try:
             top: Final = json.loads(contents)
