@@ -22,7 +22,7 @@ class TinaFormatHandler(f_base.FormatHandler):
     """Encode and decode Tina database entries."""
 
     @classmethod
-    def dumps(cls, entries: list[db.TinaEntry]) -> str:
+    def _do_dumps(cls, entries: list[db.TinaEntry]) -> str:
         """Format Tina database entries."""
 
         def dump_single(entry: db.TinaEntry, category: str | None) -> str:
@@ -40,6 +40,6 @@ class TinaFormatHandler(f_base.FormatHandler):
         return "\n".join(itertools.chain(*(dump_single_rec(entry, None) for entry in entries)))
 
     @classmethod
-    def loads(cls, contents: str) -> list[db.TinaEntry]:
+    def _do_loads(cls, contents: str) -> list[db.TinaEntry]:
         """Parse Tina database entries."""
         return parse.loads(contents)
