@@ -31,12 +31,12 @@ class YAMLFormatHandler(f_base.FormatHandler):
     """Encode and decode Tina database entries in a hierarchical structure."""
 
     @classmethod
-    def dumps(cls, entries: list[db.TinaEntry]) -> str:
+    def _do_dumps(cls, entries: list[db.TinaEntry]) -> str:
         """Format Tina database entries into the YAML structure."""
         return yaml.safe_dump(f_base.serialize(entries))
 
     @classmethod
-    def loads(cls, contents: str) -> list[db.TinaEntry]:
+    def _do_loads(cls, contents: str) -> list[db.TinaEntry]:
         """Parse the YAML structure into database entries."""
         try:
             top: Final = yaml.safe_load(contents)
