@@ -95,7 +95,7 @@ show_mode_line (struct view *v)
 	    break;
 	  }
     }
-  printw ("Items:%d]", v->s->nitems);
+  printw ("Items:%zu]", v->s->nitems);
   for (getyx (stdscr, y, x); y != -1 && x < COLS - 8; x++)
     addch ('-');
   addch('(');
@@ -104,7 +104,7 @@ show_mode_line (struct view *v)
   else if (v->selected / (LINES - 3) == ((int)v->s->nitems - 1) / (LINES - 3))
     addstr ("end");
   else
-    printw ("%d%%",
+    printw ("%zu%%",
 	    (v->selected / (LINES - 3) + 1) * (LINES - 3) * 100 / v->s->nitems);
   addstr (")---");
   lowlight ();
